package com.inspect.system.service;

import com.inspect.system.domain.SysPost;

import java.util.List;

public interface ISysPostService {
    List<SysPost> selectPostList(SysPost sysPost);

    List<SysPost> selectPostAll();

    SysPost selectPostById(Long id);

    List<Long> selectPostListByUserId(Long userId);

    String checkPostNameUnique(SysPost sysPost);

    String checkPostCodeUnique(SysPost sysPost);

    int countUserPostById(Long id);

    int deletePostById(Long id);

    int deletePostByIds(Long[] ids);

    int insertPost(SysPost sysPost);

    int updatePost(SysPost sysPost);
}
